//==============================================================================
// Tracker mutator for Unreal Tournament 2004
// Version 1.2
// 31/10/2008
// Author - Michal Bida, michal.bida@seznam.cz
//==============================================================================
class TrackerMutator extends Mutator
	config(Track);

var bool bAffectSpectators; // If this is set to true, an interaction will be created for spectators
var bool bAffectPlayers; // If this is set to true, an interaction will be created for players
var bool bHasInteraction;
var config float MyGroundSpeed, MyDrawScale;

function PreBeginPlay()
{

    log("Tracker Mutator Started"); // Always comment out your logs unless they're errors

}

event Destroyed()
{

}

simulated function Tick(float DeltaTime)
{
	local PlayerController PC;

    PC = Level.GetLocalPlayerController();

    // If the player has an interaction already, exit function.
    if (bHasInteraction)
        Return;

    // Run a check to see whether this mutator should create an interaction for the player
    if ( PC != None && ((PC.PlayerReplicationInfo.bIsSpectator && bAffectSpectators) || (bAffectPlayers && !PC.PlayerReplicationInfo.bIsSpectator)) )
    {
        PC.Player.InteractionMaster.AddInteraction("Track.TrackerInteraction", PC.Player); // Create the interaction
        bHasInteraction = True; // Set the variable so this lot isn't called again
    }
    Disable('Tick');
}

function Mutate(string MutateString, PlayerController Sender)
{
	log("We are in mutate");
	super.Mutate(MutateString, Sender);
}

function ModifyPlayer(Pawn Other)
{
	local xPawn P;

	P = xPawn(Other);

	if (P != None && !P.IsA('Monster'))
	{

		P.GroundSpeed = MyGroundSpeed;
		P.Default.GroundSpeed = MyGroundSpeed;
		P.SetDrawScale(MyDrawScale);
		//P.SetDrawScale3D(vect(MyDrawScale,MyDrawScale,MyDrawScale));


	}

	if ( NextMutator != None )
		NextMutator.ModifyPlayer(Other);
}

function ServerTraveling(string URL, bool bItems)
{
	bHasInteraction = false;
    Enable('Tick');
	super.ServerTraveling(URL,bItems);
}

DefaultProperties
{
     bAffectSpectators=true
     bAffectPlayers=true
     RemoteRole=ROLE_SimulatedProxy
     bAlwaysRelevant=true
     MyGroundSpeed=440
     MyDrawScale=1
     GroupName="Track"
     FriendlyName="Track"
     Description="The Tracking mutator."
 }
